@@ -187,7 +187,7 @@ class AxialAttention(nn.Module):
         self.attn_height = attn_class(dim = dim, heads = heads, **kwargs)
 
         self.edges_to_attn_bias = nn.Sequential(
-            nn.Linear(dim, heads),
+            nn.Linear(dim, heads, bias = False),
             Rearrange('b i j h -> b h i j')
         ) if accept_edges else None
 
@@ -212,6 +212,12 @@ class AxialAttention(nn.Module):
 
         h_rotary_emb, w_rotary_emb = cast_tuple(rotary_emb, 2)
 
+        # calculate attention bias
+
+        attn_bias = None
+        if exists(self.edges_to_attn_bias) and exists(edges):
+            attn_bias = self.edges_to_attn_bias(edges)
+
         # axial attention
 
         out = 0
@@ -219,19 +225,20 @@ class AxialAttention(nn.Module):
 
         if self.row_attn:
             w_x = rearrange(x, 'b h w d -> (b w) h d')
-            w_out = self.attn_width(w_x, mask = w_mask, rotary_emb = w_rotary_emb)
+            if exists(attn_bias):
+                attn_bias = repeat(attn_bias, 'b h i j -> (b x) h i j', x = w)
+
+            w_out = self.attn_width(w_x, mask = w_mask, rotary_emb = w_rotary_emb, attn_bias = attn_bias)
             w_out = rearrange(w_out, '(b w) h d -> b h w d', h = h, w = w)
 
             out += w_out
             axial_attn_count += 1
 
         if self.col_attn:
-            attn_bias = None
-            if exists(self.edges_to_attn_bias) and exists(edges):
-                attn_bias = self.edges_to_attn_bias(edges)
+            h_x = rearrange(x, 'b h w d -> (b h) w d')
+            if exists(attn_bias):
                 attn_bias = repeat(attn_bias, 'b h i j -> (b x) h i j', x = h)
 
-            h_x = rearrange(x, 'b h w d -> (b h) w d')
             h_out = self.attn_height(h_x, mask = h_mask, rotary_emb = h_rotary_emb, attn_bias = attn_bias)
             h_out = rearrange(h_out, '(b h) w d -> b h w d', h = h, w = w)
 
@@ -340,8 +347,8 @@ class PairwiseAttentionBlock(nn.Module):
         super().__init__()
         self.outer_mean = OuterMean(dim)
 
-        self.triangle_attention_ingoing = AxialAttention(dim = dim, heads = heads, dim_head = dim_head, row_attn = True, col_attn = False)
-        self.triangle_attention_outgoing = AxialAttention(dim = dim, heads = heads, dim_head = dim_head, row_attn = False, col_attn = True)
+        self.triangle_attention_ingoing = AxialAttention(dim = dim, heads = heads, dim_head = dim_head, row_attn = True, col_attn = False, accept_edges = True)
+        self.triangle_attention_outgoing = AxialAttention(dim = dim, heads = heads, dim_head = dim_head, row_attn = False, col_attn = True, accept_edges = True)
         self.triangle_multiply_ingoing = TriangleMultiplicativeModule(dim = dim, mix = 'ingoing')
         self.triangle_multiply_outgoing = TriangleMultiplicativeModule(dim = dim, mix = 'outgoing')
 
@@ -355,8 +362,8 @@ class PairwiseAttentionBlock(nn.Module):
         if exists(msa_repr):
             x = x + self.outer_mean(msa_repr)
 
-        x = self.triangle_attention_ingoing(x, mask = mask) + x
-        x = self.triangle_attention_outgoing(x, mask = mask) + x
+        x = self.triangle_attention_ingoing(x, edges = x, mask = mask) + x
+        x = self.triangle_attention_outgoing(x, edges = x, mask = mask) + x
         x = self.triangle_multiply_ingoing(x, mask = mask) + x
         x = self.triangle_multiply_outgoing(x, mask = mask) + x
         return x
@@ -443,7 +450,6 @@ class Alphafold2(nn.Module):
         depth = 6,
         heads = 8,
         dim_head = 64,
-        attn_types = ('full',),
         num_tokens = constants.NUM_AMINO_ACIDS,
         num_embedds = constants.NUM_EMBEDDS_TR,
         max_num_msas = constants.MAX_NUM_MSA,
@@ -451,28 +457,16 @@ class Alphafold2(nn.Module):
         attn_dropout = 0.,
         ff_dropout = 0.,
         sparse_self_attn = False,
-        msa_tie_row_attn = False,
         template_attn_depth = 2,
-        atoms = 'backbone-only',               # number of atoms to reconstitute each residue to, defaults to 3 for C, C-alpha, N
         predict_angles = False,
         symmetrize_omega = False,
         predict_coords = False,                # structure module related keyword arguments below
-        trunk_embeds_to_se3_edges = 0,         # feeds pairwise projected logits from the trunk embeddings into the equivariant transformer as edges
         return_aux_logits = False,
-        template_embedder_type = 'en',         # use E(n) Transformer for embedding templates
-        structure_module_type = 'se3',         # uses SE3 Transformer - but if set to false, will use the new E(n)-Transformer
         structure_module_dim = 4,
-        structure_module_depth = 1,
+        structure_module_depth = 4,
         structure_module_heads = 1,
         structure_module_dim_head = 4,
-        structure_module_refinement_iters = 8,
-        structure_module_knn = 2,
-        structure_module_adj_neighbors = 2,
-        structure_module_adj_dim = 4,
-        disable_token_embed = False,
-        disable_cross_attn_rotary = False,
-        structure_num_global_nodes = 0,
-        num_custom_blocks = 1
+        disable_token_embed = False
     ):
         super().__init__()
         self.dim = dim
@@ -486,10 +480,6 @@ class Alphafold2(nn.Module):
 
         self.self_attn_rotary_emb = FixedPositionalEmbedding(dim_head)
 
-        self.disable_cross_attn_rotary = disable_cross_attn_rotary
-        self.cross_attn_seq_rotary_emb = AxialRotaryEmbedding(dim_head)
-        self.cross_attn_msa_rotary_emb = FixedPositionalEmbedding((dim_head // 4) * 2)
-
         # template embedding
 
         self.template_dist_emb = nn.Embedding(constants.DISTOGRAM_BUCKETS, dim)
@@ -511,8 +501,6 @@ class Alphafold2(nn.Module):
 
         # template sidechain encoding - only if needed
 
-        self.template_embedder_type = template_embedder_type
-
         self.template_sidechain_emb = EnTransformer(
             dim = dim,
             dim_head = dim,
@@ -551,7 +539,6 @@ class Alphafold2(nn.Module):
         # to coordinate output
 
         self.predict_coords = predict_coords
-        self.structure_module_refinement_iters = structure_module_refinement_iters
 
         self.msa_to_single_repr_dim = nn.Linear(dim, structure_module_dim)
         self.trunk_to_pairwise_repr_dim = nn.Linear(dim, structure_module_dim)
